@@ -5,8 +5,8 @@ ODE_R <- function(t, y){
   ydot = vector(mode = "numeric", length = length(y))
 
   # R indices start from 1
-  ydot[1] = -0.04 * y[1] + 1e04 * y[2] * y[3]
-  ydot[3] = 3e07 * y[2] * y[2]
+  ydot[1] = -0.04 * y[1] + 10000 * y[2] * y[3]
+  ydot[3] = 30000000 * y[2] * y[2]
   ydot[2] = -ydot[1] - ydot[3]
 
   ydot
@@ -26,8 +26,8 @@ Rcpp::sourceCpp(code = '
                 // Initialize ydot filled with zeros
                 NumericVector ydot(y.length());
 
-                ydot[0] = -0.04 * y[0] + 1e04 * y[1] * y[2];
-                ydot[2] = 3e07 * y[1] * y[1];
+                ydot[0] = -0.04 * y[0] + 10000 * y[1] * y[2];
+                ydot[2] = 30000000 * y[1] * y[1];
                 ydot[1] = -ydot[0] - ydot[2];
 
                 return ydot;
